summaryrefslogtreecommitdiff
path: root/lib/Target/BPF/BPFCORE.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Target/BPF/BPFCORE.h')
-rw-r--r--lib/Target/BPF/BPFCORE.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/lib/Target/BPF/BPFCORE.h b/lib/Target/BPF/BPFCORE.h
index e0950d95f8d7..ed4778353e52 100644
--- a/lib/Target/BPF/BPFCORE.h
+++ b/lib/Target/BPF/BPFCORE.h
@@ -13,10 +13,18 @@ namespace llvm {
class BPFCoreSharedInfo {
public:
- /// The attribute attached to globals representing a member offset
+ enum OffsetRelocKind : uint32_t {
+ FIELD_BYTE_OFFSET = 0,
+ FIELD_BYTE_SIZE,
+ FIELD_EXISTENCE,
+ FIELD_SIGNEDNESS,
+ FIELD_LSHIFT_U64,
+ FIELD_RSHIFT_U64,
+
+ MAX_FIELD_RELOC_KIND,
+ };
+ /// The attribute attached to globals representing a field access
static const std::string AmaAttr;
- /// The section name to identify a patchable external global
- static const std::string PatchableExtSecName;
};
} // namespace llvm